==> php-nesbot-carbon_2.32.2.orig.tar.xz: php-nesbot-carbon-2.32.2/tests/Localization/GezTest.php <==
<?php
declare(strict_types=1);

/**
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace Tests\Localization;

class GezTest extends LocalizationTestCase
{
    const LOCALE = 'gez'; // Geez

    const CASES = [
        // Carbon::parse('2018-01-04 00:00:00')->addDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Tomorrow at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'ቀዳሚት at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'እኁድ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'ሰኑይ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'ሠሉስ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'ራብዕ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-05 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-05 00:00:00'))
        'ሐሙስ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-06 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-06 00:00:00'))
        'ዓርበ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'ሠሉስ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'ራብዕ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'ሐሙስ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'ዓርበ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'ቀዳሚት at 12:00 ጽባሕ',
        // Carbon::now()->subDays(2)->calendar()
        'Last እኁድ at 8:49 ምሴት',
        // Carbon::parse('2018-01-04 00:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Yesterday at 10:00 ምሴት',
        // Carbon::parse('2018-01-04 12:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 12:00:00'))
        'Today at 10:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Today at 2:00 ጽባሕ',
        // Carbon::parse('2018-01-04 23:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 23:00:00'))
        'Tomorrow at 1:00 ጽባሕ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'ሠሉስ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-08 00:00:00')->subDay()->calendar(Carbon::parse('2018-01-08 00:00:00'))
        'Yesterday at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Yesterday at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last ሠሉስ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last ሰኑይ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last እኁድ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last ቀዳሚት at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last ዓርበ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-03 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-03 00:00:00'))
        'Last ሐሙስ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-02 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-02 00:00:00'))
        'Last ራብዕ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-07 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Last ዓርበ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-01 00:00:00')->isoFormat('Qo Mo Do Wo wo')
        '1st 1st 1st 1st 1st',
        // Carbon::parse('2018-01-02 00:00:00')->isoFormat('Do wo')
        '2nd 1st',
        // Carbon::parse('2018-01-03 00:00:00')->isoFormat('Do wo')
        '3rd 1st',
        // Carbon::parse('2018-01-04 00:00:00')->isoFormat('Do wo')
        '4th 1st',
        // Carbon::parse('2018-01-05 00:00:00')->isoFormat('Do wo')
        '5th 1st',
        // Carbon::parse('2018-01-06 00:00:00')->isoFormat('Do wo')
        '6th 1st',
        // Carbon::parse('2018-01-07 00:00:00')->isoFormat('Do wo')
        '7th 1st',
        // Carbon::parse('2018-01-11 00:00:00')->isoFormat('Do wo')
        '11th 2nd',
        // Carbon::parse('2018-02-09 00:00:00')->isoFormat('DDDo')
        '40th',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('DDDo')
        '41st',
        // Carbon::parse('2018-04-10 00:00:00')->isoFormat('DDDo')
        '100th',
        // Carbon::parse('2018-02-10 00:00:00', 'Europe/Paris')->isoFormat('h:mm a z')
        '12:00 ጽባሕ CET',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 ጽባሕ, 12:00 ጽባሕ',
        // Carbon::parse('2018-02-10 01:30:00')->isoFormat('h:mm A, h:mm a')
        '1:30 ጽባሕ, 1:30 ጽባሕ',
        // Carbon::parse('2018-02-10 02:00:00')->isoFormat('h:mm A, h:mm a')
        '2:00 ጽባሕ, 2:00 ጽባሕ',
        // Carbon::parse('2018-02-10 06:00:00')->isoFormat('h:mm A, h:mm a')
        '6:00 ጽባሕ, 6:00 ጽባሕ',
        // Carbon::parse('2018-02-10 10:00:00')->isoFormat('h:mm A, h:mm a')
        '10:00 ጽባሕ, 10:00 ጽባሕ',
        // Carbon::parse('2018-02-10 12:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 ምሴት, 12:00 ምሴት',
        // Carbon::parse('2018-02-10 17:00:00')->isoFormat('h:mm A, h:mm a')
        '5:00 ምሴት, 5:00 ምሴት',
        // Carbon::parse('2018-02-10 21:30:00')->isoFormat('h:mm A, h:mm a')
        '9:30 ምሴት, 9:30 ምሴት',
        // Carbon::parse('2018-02-10 23:00:00')->isoFormat('h:mm A, h:mm a')
        '11:00 ምሴት, 11:00 ምሴት',
        // Carbon::parse('2018-01-01 00:00:00')->ordinal('hour')
        '0th',
        // Carbon::now()->subSeconds(1)->diffForHumans()
        '1 ካልእ ago',
        // Carbon::now()->subSeconds(1)->diffForHumans(null, false, true)
        '1 ካልእ ago',
        // Carbon::now()->subSeconds(2)->diffForHumans()
        '2 ካልእ ago',
        // Carbon::now()->subSeconds(2)->diffForHumans(null, false, true)
        '2 ካልእ ago',
        // Carbon::now()->subMinutes(1)->diffForHumans()
        '1 ንኡስ ago',
        // Carbon::now()->subMinutes(1)->diffForHumans(null, false, true)
        '1 ንኡስ ago',
        // Carbon::now()->subMinutes(2)->diffForHumans()
        '2 ንኡስ ago',
        // Carbon::now()->subMinutes(2)->diffForHumans(null, false, true)
        '2 ንኡስ ago',
        // Carbon::now()->subHours(1)->diffForHumans()
        '1 አንትሙ ago',
        // Carbon::now()->subHours(1)->diffForHumans(null, false, true)
        '1 አንትሙ ago',
        // Carbon::now()->subHours(2)->diffForHumans()
        '2 አንትሙ ago',
        // Carbon::now()->subHours(2)->diffForHumans(null, false, true)
        '2 አንትሙ ago',
        // Carbon::now()->subDays(1)->diffForHumans()
        '1 ዕለት ago',
        // Carbon::now()->subDays(1)->diffForHumans(null, false, true)
        '1 ዕለት ago',
        // Carbon::now()->subDays(2)->diffForHumans()
        '2 ዕለት ago',
        // Carbon::now()->subDays(2)->diffForHumans(null, false, true)
        '2 ዕለት ago',
        // Carbon::now()->subWeeks(1)->diffForHumans()
        '1 ሰብዑ ago',
        // Carbon::now()->subWeeks(1)->diffForHumans(null, false, true)
        '1 ሰብዑ ago',
        // Carbon::now()->subWeeks(2)->diffForHumans()
        '2 ሰብዑ ago',
        // Carbon::now()->subWeeks(2)->diffForHumans(null, false, true)
        '2 ሰብዑ ago',
        // Carbon::now()->subMonths(1)->diffForHumans()
        '1 ወርሕ ago',
        // Carbon::now()->subMonths(1)->diffForHumans(null, false, true)
        '1 ወርሕ ago',
        // Carbon::now()->subMonths(2)->diffForHumans()
        '2 ወርሕ ago',
        // Carbon::now()->subMonths(2)->diffForHumans(null, false, true)
        '2 ወርሕ ago',
        // Carbon::now()->subYears(1)->diffForHumans()
        '1 ዓመት ago',
        // Carbon::now()->subYears(1)->diffForHumans(null, false, true)
        '1 ዓመት ago',
        // Carbon::now()->subYears(2)->diffForHumans()
        '2 ዓመት ago',
        // Carbon::now()->subYears(2)->diffForHumans(null, false, true)
        '2 ዓመት ago',
        // Carbon::now()->addSecond()->diffForHumans()
        '1 ካልእ from now',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true)
        '1 ካልእ from now',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now())
        '1 ካልእ after',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), false, true)
        '1 ካልእ after',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond())
        '1 ካልእ before',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond(), false, true)
        '1 ካልእ before',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true)
        '1 ካልእ',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true, true)
        '1 ካልእ',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true)
        '2 ካልእ',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true, true)
        '2 ካልእ',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true, 1)
        '1 ካልእ from now',
        // Carbon::now()->addMinute()->addSecond()->diffForHumans(null, true, false, 2)
        '1 ንኡስ 1 ካልእ',
        // Carbon::now()->addYears(2)->addMonths(3)->addDay()->addSecond()->diffForHumans(null, true, true, 4)
        '2 ዓመት 3 ወርሕ 1 ዕለት 1 ካልእ',
        // Carbon::now()->addYears(3)->diffForHumans(null, null, false, 4)
        '3 ዓመት from now',
        // Carbon::now()->subMonths(5)->diffForHumans(null, null, true, 4)
        '5 ወርሕ ago',
        // Carbon::now()->subYears(2)->subMonths(3)->subDay()->subSecond()->diffForHumans(null, null, true, 4)
        '2 ዓመት 3 ወርሕ 1 ዕለት 1 ካልእ ago',
        // Carbon::now()->addWeek()->addHours(10)->diffForHumans(null, true, false, 2)
        '1 ሰብዑ 10 አንትሙ',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        '1 ሰብዑ 6 ዕለት',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        '1 ሰብዑ 6 ዕለት',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(["join" => true, "parts" => 2])
        '1 ሰብዑ and 6 ዕለት from now',
        // Carbon::now()->addWeeks(2)->addHour()->diffForHumans(null, true, false, 2)
        '2 ሰብዑ 1 አንትሙ',
        // Carbon::now()->addHour()->diffForHumans(["aUnit" => true])
        '1 አንትሙ from now',
        // CarbonInterval::days(2)->forHumans()
        '2 ዕለት',
        // CarbonInterval::create('P1DT3H')->forHumans(true)
        '1 ዕለት 3 አንትሙ',
    ];
}

==> php-nesbot-carbon_2.65.0.orig.tar.xz: php-nesbot-carbon-2.65.0/tests/Localization/GezTest.php <==
<?php

declare(strict_types=1);

/**
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Tests\Localization;

/**
 * @group localization
 */
class GezTest extends LocalizationTestCase
{
    public const LOCALE = 'gez'; // Geez

    public const CASES = [
        // Carbon::parse('2018-01-04 00:00:00')->addDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Tomorrow at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'ቀዳሚት at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'እኁድ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'ሰኑይ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'ሠሉስ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'ራብዕ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-05 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-05 00:00:00'))
        'ሐሙስ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-06 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-06 00:00:00'))
        'ዓርበ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'ሠሉስ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'ራብዕ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'ሐሙስ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'ዓርበ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'ቀዳሚት at 12:00 ጽባሕ',
        // Carbon::now()->subDays(2)->calendar()
        'Last እኁድ at 8:49 ምሴት',
        // Carbon::parse('2018-01-04 00:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Yesterday at 10:00 ምሴት',
        // Carbon::parse('2018-01-04 12:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 12:00:00'))
        'Today at 10:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Today at 2:00 ጽባሕ',
        // Carbon::parse('2018-01-04 23:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 23:00:00'))
        'Tomorrow at 1:00 ጽባሕ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'ሠሉስ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-08 00:00:00')->subDay()->calendar(Carbon::parse('2018-01-08 00:00:00'))
        'Yesterday at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Yesterday at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last ሠሉስ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last ሰኑይ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last እኁድ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last ቀዳሚት at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last ዓርበ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-03 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-03 00:00:00'))
        'Last ሐሙስ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-02 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-02 00:00:00'))
        'Last ራብዕ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-07 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Last ዓርበ at 12:00 ጽባሕ',
        // Carbon::parse('2018-01-01 00:00:00')->isoFormat('Qo Mo Do Wo wo')
        '1st 1st 1st 1st 1st',
        // Carbon::parse('2018-01-02 00:00:00')->isoFormat('Do wo')
        '2nd 1st',
        // Carbon::parse('2018-01-03 00:00:00')->isoFormat('Do wo')
        '3rd 1st',
        // Carbon::parse('2018-01-04 00:00:00')->isoFormat('Do wo')
        '4th 1st',
        // Carbon::parse('2018-01-05 00:00:00')->isoFormat('Do wo')
        '5th 1st',
        // Carbon::parse('2018-01-06 00:00:00')->isoFormat('Do wo')
        '6th 1st',
        // Carbon::parse('2018-01-07 00:00:00')->isoFormat('Do wo')
        '7th 1st',
        // Carbon::parse('2018-01-11 00:00:00')->isoFormat('Do wo')
        '11th 2nd',
        // Carbon::parse('2018-02-09 00:00:00')->isoFormat('DDDo')
        '40th',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('DDDo')
        '41st',
        // Carbon::parse('2018-04-10 00:00:00')->isoFormat('DDDo')
        '100th',
        // Carbon::parse('2018-02-10 00:00:00', 'Europe/Paris')->isoFormat('h:mm a z')
        '12:00 ጽባሕ CET',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 ጽባሕ, 12:00 ጽባሕ',
        // Carbon::parse('2018-02-10 01:30:00')->isoFormat('h:mm A, h:mm a')
        '1:30 ጽባሕ, 1:30 ጽባሕ',
        // Carbon::parse('2018-02-10 02:00:00')->isoFormat('h:mm A, h:mm a')
        '2:00 ጽባሕ, 2:00 ጽባሕ',
        // Carbon::parse('2018-02-10 06:00:00')->isoFormat('h:mm A, h:mm a')
        '6:00 ጽባሕ, 6:00 ጽባሕ',
        // Carbon::parse('2018-02-10 10:00:00')->isoFormat('h:mm A, h:mm a')
        '10:00 ጽባሕ, 10:00 ጽባሕ',
        // Carbon::parse('2018-02-10 12:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 ምሴት, 12:00 ምሴት',
        // Carbon::parse('2018-02-10 17:00:00')->isoFormat('h:mm A, h:mm a')
        '5:00 ምሴት, 5:00 ምሴት',
        // Carbon::parse('2018-02-10 21:30:00')->isoFormat('h:mm A, h:mm a')
        '9:30 ምሴት, 9:30 ምሴት',
        // Carbon::parse('2018-02-10 23:00:00')->isoFormat('h:mm A, h:mm a')
        '11:00 ምሴት, 11:00 ምሴት',
        // Carbon::parse('2018-01-01 00:00:00')->ordinal('hour')
        '0th',
        // Carbon::now()->subSeconds(1)->diffForHumans()
        '1 ካልእ ago',
        // Carbon::now()->subSeconds(1)->diffForHumans(null, false, true)
        '1 ካልእ ago',
        // Carbon::now()->subSeconds(2)->diffForHumans()
        '2 ካልእ ago',
        // Carbon::now()->subSeconds(2)->diffForHumans(null, false, true)
        '2 ካልእ ago',
        // Carbon::now()->subMinutes(1)->diffForHumans()
        '1 ንኡስ ago',
        // Carbon::now()->subMinutes(1)->diffForHumans(null, false, true)
        '1 ንኡስ ago',
        // Carbon::now()->subMinutes(2)->diffForHumans()
        '2 ንኡስ ago',
        // Carbon::now()->subMinutes(2)->diffForHumans(null, false, true)
        '2 ንኡስ ago',
        // Carbon::now()->subHours(1)->diffForHumans()
        '1 አንትሙ ago',
        // Carbon::now()->subHours(1)->diffForHumans(null, false, true)
        '1 አንትሙ ago',
        // Carbon::now()->subHours(2)->diffForHumans()
        '2 አንትሙ ago',
        // Carbon::now()->subHours(2)->diffForHumans(null, false, true)
        '2 አንትሙ ago',
        // Carbon::now()->subDays(1)->diffForHumans()
        '1 ዕለት ago',
        // Carbon::now()->subDays(1)->diffForHumans(null, false, true)
        '1 ዕለት ago',
        // Carbon::now()->subDays(2)->diffForHumans()
        '2 ዕለት ago',
        // Carbon::now()->subDays(2)->diffForHumans(null, false, true)
        '2 ዕለት ago',
        // Carbon::now()->subWeeks(1)->diffForHumans()
        '1 ሰብዑ ago',
        // Carbon::now()->subWeeks(1)->diffForHumans(null, false, true)
        '1 ሰብዑ ago',
        // Carbon::now()->subWeeks(2)->diffForHumans()
        '2 ሰብዑ ago',
        // Carbon::now()->subWeeks(2)->diffForHumans(null, false, true)
        '2 ሰብዑ ago',
        // Carbon::now()->subMonths(1)->diffForHumans()
        '1 ወርሕ ago',
        // Carbon::now()->subMonths(1)->diffForHumans(null, false, true)
        '1 ወርሕ ago',
        // Carbon::now()->subMonths(2)->diffForHumans()
        '2 ወርሕ ago',
        // Carbon::now()->subMonths(2)->diffForHumans(null, false, true)
        '2 ወርሕ ago',
        // Carbon::now()->subYears(1)->diffForHumans()
        '1 ዓመት ago',
        // Carbon::now()->subYears(1)->diffForHumans(null, false, true)
        '1 ዓመት ago',
        // Carbon::now()->subYears(2)->diffForHumans()
        '2 ዓመት ago',
        // Carbon::now()->subYears(2)->diffForHumans(null, false, true)
        '2 ዓመት ago',
        // Carbon::now()->addSecond()->diffForHumans()
        '1 ካልእ from now',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true)
        '1 ካልእ from now',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now())
        '1 ካልእ after',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), false, true)
        '1 ካልእ after',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond())
        '1 ካልእ before',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond(), false, true)
        '1 ካልእ before',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true)
        '1 ካልእ',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true, true)
        '1 ካልእ',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true)
        '2 ካልእ',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true, true)
        '2 ካልእ',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true, 1)
        '1 ካልእ from now',
        // Carbon::now()->addMinute()->addSecond()->diffForHumans(null, true, false, 2)
        '1 ንኡስ 1 ካልእ',
        // Carbon::now()->addYears(2)->addMonths(3)->addDay()->addSecond()->diffForHumans(null, true, true, 4)
        '2 ዓመት 3 ወርሕ 1 ዕለት 1 ካልእ',
        // Carbon::now()->addYears(3)->diffForHumans(null, null, false, 4)
        '3 ዓመት from now',
        // Carbon::now()->subMonths(5)->diffForHumans(null, null, true, 4)
        '5 ወርሕ ago',
        // Carbon::now()->subYears(2)->subMonths(3)->subDay()->subSecond()->diffForHumans(null, null, true, 4)
        '2 ዓመት 3 ወርሕ 1 ዕለት 1 ካልእ ago',
        // Carbon::now()->addWeek()->addHours(10)->diffForHumans(null, true, false, 2)
        '1 ሰብዑ 10 አንትሙ',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        '1 ሰብዑ 6 ዕለት',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        '1 ሰብዑ 6 ዕለት',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(["join" => true, "parts" => 2])
        '1 ሰብዑ and 6 ዕለት from now',
        // Carbon::now()->addWeeks(2)->addHour()->diffForHumans(null, true, false, 2)
        '2 ሰብዑ 1 አንትሙ',
        // Carbon::now()->addHour()->diffForHumans(["aUnit" => true])
        '1 አንትሙ from now',
        // CarbonInterval::days(2)->forHumans()
        '2 ዕለት',
        // CarbonInterval::create('P1DT3H')->forHumans(true)
        '1 ዕለት 3 አንትሙ',
    ];
}
